@@ -72,9 +72,12 @@ vector<differences_str> Alignment::summarizeAlignment() {
 	vector<differences_str> events;
 	int pos = this->getPosition();
 	differences_str ev;
-	bool flag = false; // (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
+	bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
 
 	for (size_t i = 0; i < al->CigarData.size(); i++) {
+		if (flag) {
+			//	cout<<al->CigarData[i].Type<<al->CigarData[i].Length<<std::endl;
+		}
 		if (al->CigarData[i].Type == 'D') {
 			ev.position = pos;
 			ev.type = al->CigarData[i].Length; //deletion
@@ -88,28 +91,29 @@ vector<differences_str> Alignment::summarizeAlignment() {
 			pos += al->CigarData[i].Length;
 		} else if (al->CigarData[i].Type == 'N') {
 			pos += al->CigarData[i].Length;
-		}
-		/*else if (al->CigarData[i].Type == 'S' && al->CigarData[i].Length > Parameter::Instance()->huge_ins) { /// Used for reads ranging into an inser
+		} else if (al->CigarData[i].Type == 'S' && al->CigarData[i].Length > Parameter::Instance()->huge_ins) { /// Used for reads ranging into an inser
 			string sa;
 			al->GetTag("SA", sa);
-			if (sa.empty()) { // == no split reads!
+			uint32_t sv;
+			if ((al->GetTag("SV", sv) && sa.empty()) && (!(sv & Ns_CLIPPED) && !(sv & FULLY_EXPLAINED))) { // TODO remove last )
 				if (flag) {
 					std::cout << "Chop: " << pos << " Rname: " << this->getName() << std::endl;
 				}
 				if (pos == this->getPosition()) {
-					ev.position = pos - Parameter::Instance()->huge_ins;
+					ev.position = pos; // - Parameter::Instance()->huge_ins;
 				} else {
 					ev.position = pos;
 				}
 				ev.type = Parameter::Instance()->huge_ins * -1; //insertion: WE have to fix the length since we cannot estimate it!]
 				events.push_back(ev);
 			}
-		}*/
+		}
 	}
 
 	if (flag) {
+		std::cout << "FIRST:" << std::endl;
 		for (size_t i = 0; i < events.size(); i++) {
-			if (abs(events[i].type) > 3000) {
+			if (abs(events[i].type) > 200) {
 				cout << events[i].position << " " << events[i].type << endl;
 			}
 		}
@@ -158,8 +162,9 @@ vector<differences_str> Alignment::summarizeAlignment() {
 	}
 
 	if (flag) {
+		std::cout << "SECOND:" << std::endl;
 		for (size_t i = 0; i < events.size(); i++) {
-			if (abs(events[i].type) > 3000) {
+			if (abs(events[i].type) > 200) {
 				cout << events[i].position << " " << events[i].type << endl;
 			}
 		}
@@ -170,43 +175,44 @@ vector<differences_str> Alignment::summarizeAlignment() {
 //	comp_aln = clock();
 	size_t i = 0;
 	//to erase stretches of consecutive mismatches == N in the ref
-	int break_point = 0;
-	while (i < events.size()) {
-		if (events[i].position > max_size) {
-			while (i < events.size()) {
-				if (abs(events[events.size() - 1].type) == Parameter::Instance()->huge_ins) {
-					i++;
-				} else {
-					events.erase(events.begin() + i, events.begin() + i + 1);
-				}
-			}
-			break;
-		}
-		if (events[i].type == 0) {
-			size_t j = 1;
-			while (i + j < events.size() && ((events[i + j].position - events[i + (j - 1)].position) == 1 && events[i + j].type == 0)) {
-				j++;
-			}
-			if (j > 10) { //if stetch is at least 3 consecutive mismatches
-				events.erase(events.begin() + i, events.begin() + i + j);
-			} else {
-				i += j;
-			}
-		} else {
-			i++;
-		}
-	}
+	/*int break_point = 0;
+	 while (i < events.size()) {
+	 if (events[i].position > max_size) {
+	 while (i < events.size()) {
+	 if (abs(events[events.size() - 1].type) == Parameter::Instance()->huge_ins) {
+	 i++;
+	 } else {
+	 events.erase(events.begin() + i, events.begin() + i + 1);
+	 }
+	 }
+	 break;
+	 }
+	 if (events[i].type == 0) {
+	 size_t j = 1;
+	 while (i + j < events.size() && ((events[i + j].position - events[i + (j - 1)].position) == 1 && events[i + j].type == 0)) {
+	 j++;
+	 }
+	 if (j > 10) { //if stetch is at least 3 consecutive mismatches
+	 events.erase(events.begin() + i, events.begin() + i + j);
+	 } else {
+	 i += j;
+	 }
+	 } else {
+	 i++;
+	 }
+	 }*/
 //	Parameter::Instance()->meassure_time(comp_aln, "\t\terrase N: ");
 	if (flag) {
 		cout << "LAST:" << endl;
 		for (size_t i = 0; i < events.size(); i++) {
-			if (abs(events[i].type) > 3000) {
+			if (abs(events[i].type) > 200) {
 				cout << events[i].position << " " << events[i].type << endl;
 			}
 		}
 		cout << endl;
-	}
 
+		cout << "total: " << events.size() << endl;
+	}
 	return events;
 }
 void Alignment::computeAlignment() {
@@ -464,7 +470,8 @@ void Alignment::get_coords(aln_str tmp, int & start, int &stop) {
 }
 void Alignment::check_entries(vector<aln_str> &entries) {
 
-	bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
+	bool flag =(strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
+
 	if (flag) {
 		std::cout << "Nested? " << std::endl;
 		for (size_t i = 0; i < entries.size(); i++) {
@@ -474,16 +481,34 @@ void Alignment::check_entries(vector<aln_str> &entries) {
 			} else {
 				std::cout << "- ";
 			}
+			//sort_insert_ref(entries[i], new_entries);
 		}
 		std::cout << std::endl;
+
 	}
+
 	int chr = entries[0].RefID;
 	bool strand = entries[0].strand;
 	int strands = 1;
 	int valid = 1;
+	double read_gaps = 0;
+	double ref_gaps = 0;
+
+	int ref_size = 0;
+	int read_size = 0;
+
 	for (size_t i = 1; i < entries.size(); i++) {
-		if (entries[i].read_pos_stop - entries[i].read_pos_start > 200) {
-			valid++;
+		if (entries[i].read_pos_stop - entries[i].read_pos_start > 200) { //only consider segments > 200bp.
+			ref_size = min((int) abs((entries[i - 1].pos + entries[i - 1].length) - entries[i].pos), (int) abs(entries[i - 1].pos - (entries[i].pos + entries[i].length)));
+
+			read_size = abs(entries[i - 1].read_pos_stop - entries[i].read_pos_start);
+			if (abs(ref_size - read_size) > Parameter::Instance()->min_length) {
+				valid++;
+			}
+			if(flag){
+			cout<<"Read: "<<read_size << " Ref: "<<ref_size<< " "<<this->getName()<<std::endl;
+			}
+
 			if (chr != entries[i].RefID) {
 				return;
 			}
@@ -493,10 +518,14 @@ void Alignment::check_entries(vector<aln_str> &entries) {
 			}
 		}
 	}
+
 	if (flag) {
-		std::cout << "summary: " << strands << " " << valid << std::endl;
+		std::cout << "summary: " << strands << " " << valid << " " << std::endl;
 	}
-	if (strands < 3 || valid < 3) {
+	if (strands < 3 || valid < 2 ) { //check!
+		if (flag) {
+			std::cout << "Return" << std::endl;
+		}
 		return;
 	}
 
@@ -511,6 +540,9 @@ void Alignment::check_entries(vector<aln_str> &entries) {
 			read_dist = abs(entries[i - 1].read_pos_stop - entries[i].read_pos_start);
 		}
 
+		if (flag) {
+			std::cout << "REF DIST: " << ref_dist << " READ DIST: " << read_dist << std::endl;
+		}
 		if (abs(entries[i - 1].pos - entries[i].pos) < 100) { //inv dup:
 			aln_str tmp;
 			tmp.RefID = entries[i].RefID;
@@ -659,19 +691,21 @@ void Alignment::check_entries(vector<aln_str> &entries) {
  entries = new_entries;
  }
  }*/
+
+void Alignment::sort_insert_ref(aln_str tmp, vector<aln_str> &entries) {
+
+	for (vector<aln_str>::iterator i = entries.begin(); i != entries.end(); i++) {
+		if ((tmp.pos < (*i).pos)) { //insert before
+			entries.insert(i, tmp);
+			return;
+		}
+	}
+	entries.push_back(tmp);
+}
+
 void Alignment::sort_insert(aln_str tmp, vector<aln_str> &entries) {
 
 	for (vector<aln_str>::iterator i = entries.begin(); i != entries.end(); i++) {
-		/*	if ((tmp.read_pos_start == (*i).read_pos_start) && (tmp.pos == (*i).pos) && (tmp.strand == (*i).strand)) { //is the same! should not happen
-		 return;
-		 }
-		 if (!tmp.cigar.empty() && ((*i).read_pos_start <= tmp.read_pos_start && (*i).read_pos_stop >= tmp.read_pos_stop)) { //check for the additional introducded entries
-		 return;
-		 }
-		 if (!tmp.cigar.empty() && ((*i).read_pos_start >= tmp.read_pos_start && (*i).read_pos_stop <= tmp.read_pos_stop)) { //check for the additional introducded entries
-		 (*i) = tmp;
-		 return;
-		 }*/
 		if ((tmp.read_pos_start < (*i).read_pos_start)) { //insert before
 			entries.insert(i, tmp);
 			return;
@@ -702,6 +736,9 @@ vector<aln_str> Alignment::getSA(RefVector ref) {
 		tmp.mq = this->getMappingQual();
 		tmp.pos = (long) this->getPosition(); //+get_ref_lengths(tmp.RefID, ref);
 		tmp.strand = getStrand();
+		uint32_t sv;
+		al->GetTag("SV", sv);
+		tmp.cross_N = ((sv & Ns_CLIPPED));
 		bool flag = strcmp(getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0;
 
 		get_coords(tmp, tmp.read_pos_start, tmp.read_pos_stop);
@@ -739,7 +776,8 @@ vector<aln_str> Alignment::getSA(RefVector ref) {
 				count++;
 			}
 			if (sa[i] == ';') {
-				if (tmp.mq > Parameter::Instance()->min_mq && entries.size() <= Parameter::Instance()->max_splits) {
+				//TODO: maybe check how often this happens per read!
+				if ((tmp.mq > Parameter::Instance()->min_mq || sv & FULLY_EXPLAINED) && entries.size() <= Parameter::Instance()->max_splits) {
 					//TODO: check this!
 					tmp.cigar = translate_cigar(cigar); //translates the cigar (string) to a type vector
 					get_coords(tmp, tmp.read_pos_start, tmp.read_pos_stop); //get the coords on the read.
@@ -758,6 +796,9 @@ vector<aln_str> Alignment::getSA(RefVector ref) {
 					//insert sorted:
 					includes_SV = true;
 					sort_insert(tmp, entries);
+
+					//al->GetTag("SV", sv);   <-get that involved
+
 				} else if (tmp.mq < Parameter::Instance()->min_mq) {
 					nested = false;
 				} else {					//Ignore read due to too many splits
@@ -772,7 +813,7 @@ vector<aln_str> Alignment::getSA(RefVector ref) {
 			}
 			i++;
 		}
-		if (nested && entries.size() > 2 || overlapping_segments(entries)) {
+		if (nested && (entries.size() > 2 || overlapping_segments(entries))) {
 			check_entries(entries);
 		}
 		if (flag) {
@@ -793,11 +834,11 @@ vector<aln_str> Alignment::getSA(RefVector ref) {
 double Alignment::get_scrore_ratio() {
 	uint score = -1;
 	uint subscore = -1;
-	if (al->GetTag("AS", score) && al->GetTag("XS", subscore)) {
+	if (al->GetTag("AS", score)) {
+		al->GetTag("XS", subscore);
 		if (subscore == 0) {
 			subscore = 1;
 		}
-		//cout<<'\t'<<score<<" "<<subscore<<endl;
 		return (double) score / (double) subscore;
 	}
 	return -1;
@@ -805,16 +846,9 @@ double Alignment::get_scrore_ratio() {
 bool Alignment::get_is_save() {
 	string sa;
 
-	double score = get_scrore_ratio();
+	double score = get_scrore_ratio(); //TODO should I use this again for bwa?
 
-	/*if((al->GetTag("XA", sa) && !sa.empty())){
-	 std::cout<<this->getName()<<"XA"<<std::endl;
-	 }
-	 if( (al->GetTag("XT", sa) && !sa.empty()) ){
-	 std::cout<<this->getName()<<"XT"<<std::endl;
-	 }*/
-
-	return !((al->GetTag("XA", sa) && !sa.empty()) || (al->GetTag("XT", sa) && !sa.empty()));					//|| (score == -1 || score < Parameter::Instance()->score_treshold)); //TODO: 7.5
+	return !((al->GetTag("XA", sa) && !sa.empty()) || (al->GetTag("XT", sa) && !sa.empty())) && (score == -1 || score > Parameter::Instance()->score_treshold);					//|| //TODO: 7.5
 }
 
 std::vector<CigarOp> Alignment::translate_cigar(std::string cigar) {
@@ -1046,7 +1080,7 @@ vector<str_event> Alignment::get_events_MD(int min_mis) {
 	return events;
 }
 
-vector<int> Alignment::get_avg_diff(double & dist) {
+vector<int> Alignment::get_avg_diff(double & dist, double & avg_del, double & avg_ins) {
 
 //computeAlignment();
 //cout<<alignment.first<<endl;
@@ -1061,10 +1095,15 @@ vector<int> Alignment::get_avg_diff(double & dist) {
 	PlaneSweep_slim * plane = new PlaneSweep_slim();
 	int min_tresh = 5; //reflects a 10% error rate.
 //compute the profile of differences:
+	double del = 0;
+	double ins = 0;
+	double mis = 0;
+	double length = event_aln[event_aln.size() - 1].position - event_aln[0].position;
 	for (size_t i = 0; i < event_aln.size(); i++) {
 		if (i != 0) {
 			dist += event_aln[i].position - event_aln[i - 1].position;
 		}
+
 		pair_str tmp;
 		tmp.position = -1;
 		if (event_aln[i].type == 0) {
@@ -1075,7 +1114,16 @@ vector<int> Alignment::get_avg_diff(double & dist) {
 		if (tmp.position != -1) { //check that its not the prev event!
 			mis_per_window.push_back(tmp.coverage); //store #mismatch per window each time it exceeds. (which might be every event position!)
 		}
+		if (event_aln[i].type > 0) {
+			avg_del += event_aln[i].type;
+		} else if (event_aln[i].type < 0) {
+			avg_ins += event_aln[i].type * -1;
+		}
 	}
+
+	avg_ins = avg_ins / length;
+	avg_del = avg_del / length;
+
 	dist = dist / (double) event_aln.size();
 	plane->finalyze();
 	return mis_per_window;	//total_num /num;
@@ -1083,8 +1131,13 @@ vector<int> Alignment::get_avg_diff(double & dist) {
 
 vector<str_event> Alignment::get_events_Aln() {
 
+	bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
+
 //clock_t comp_aln = clock();
 	vector<differences_str> event_aln = summarizeAlignment();
+	if (flag) {
+		std::cout << "test size: " << event_aln.size() << std::endl;
+	}
 //double time2 = Parameter::Instance()->meassure_time(comp_aln, "\tcompAln Events: ");
 
 	vector<str_event> events;
@@ -1092,7 +1145,11 @@ vector<str_event> Alignment::get_events_Aln() {
 	vector<pair_str> profile;
 //	comp_aln = clock();
 
-	bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
+	bool is_N_region = false;
+	uint32_t sv;
+	if (al->GetTag("SV", sv) && (!(sv & Ns_CLIPPED) && !(sv & FULLY_EXPLAINED))) {
+		is_N_region = true;
+	}
 
 	int noise_events = 0;
 //compute the profile of differences:
@@ -1116,10 +1173,13 @@ vector<str_event> Alignment::get_events_Aln() {
 	}
 
 //comp_aln = clock();
-	size_t stop = 0;
+	int stop = 0;
 	size_t start = 0;
-	for (size_t i = 0; i < profile.size(); i++) {
-		if (profile[i].position > event_aln[stop].position) {
+	for (size_t i = 0; i < profile.size() && stop < event_aln.size(); i++) {
+		if (flag) {
+			std::cout << "Prof: " << profile[i].position << " " << event_aln[stop].position << std::endl;
+		}
+		if (profile[i].position >= event_aln[stop].position) {
 			//find the postion:
 			size_t pos = 0;
 			while (pos < event_aln.size() && event_aln[pos].position != profile[i].position) {
@@ -1130,6 +1190,9 @@ vector<str_event> Alignment::get_events_Aln() {
 			int prev = event_aln[pos].position;
 			start = pos;
 			int prev_type = 1;
+			if (flag) {
+				std::cout << "check start" << std::endl;
+			}
 			//todo it is actually pos + type and not *type
 			while (start > 0 && (prev - event_aln[start].position) < (Parameter::Instance()->max_dist_alns)) {	//13		//} * abs(event_aln[start].type) + 1)) { //TODO I  dont like 13!??
 				prev = event_aln[start].position;
@@ -1147,7 +1210,9 @@ vector<str_event> Alignment::get_events_Aln() {
 			prev = event_aln[pos].position;
 			stop = pos;
 			prev_type = 1;
-
+			if (flag) {
+				std::cout << "check stop" << std::endl;
+			}
 			while (stop < event_aln.size() && (event_aln[stop].position - prev) < (Parameter::Instance()->max_dist_alns)) {		// * abs(event_aln[stop].type) + 1)) {
 				prev = event_aln[stop].position;
 
@@ -1158,8 +1223,9 @@ vector<str_event> Alignment::get_events_Aln() {
 				}
 				prev += prev_type;
 			}
-			stop--;
-
+			if (stop > 0) {
+				stop--;
+			}
 			int insert_max_pos = 0;
 			int insert_max = 0;
 			if (event_aln[start].type < 0) {
@@ -1173,13 +1239,13 @@ vector<str_event> Alignment::get_events_Aln() {
 			double insert = 0;
 			double del = 0;
 			double mismatch = 0;
+//			if (flag) {
+//				cout << start << " " << stop << endl;
+//			}
 			if (flag) {
-				cout << start << " " << stop << endl;
+				std::cout << "check total len: " << start << " " << stop << std::endl;
 			}
 			for (size_t k = start; k <= stop; k++) {
-				if (flag) {
-					cout << event_aln[k].position << " " << event_aln[k].type << endl;
-				}
 				if (event_aln[k].type == 0) {
 					mismatch++;
 				} else if (event_aln[k].type > 0) {
@@ -1205,6 +1271,9 @@ vector<str_event> Alignment::get_events_Aln() {
 			}
 			tmp.length = (tmp.length - event_aln[start].position);
 
+			if (flag) {
+				std::cout << "decide" << std::endl;
+			}
 			tmp.type = 0;
 			if (insert_max > Parameter::Instance()->min_length && insert > (del + del)) { //we have an insertion! //todo check || vs. &&
 				if (flag) {
@@ -1214,6 +1283,9 @@ vector<str_event> Alignment::get_events_Aln() {
 				tmp.pos = insert_max_pos;
 				tmp.type |= INS;
 				tmp.is_noise = false;
+				if (is_N_region && insert_max * Parameter::Instance()->avg_ins < Parameter::Instance()->min_length) {
+					tmp.type = 0;
+				}
 			} else if (del_max > Parameter::Instance()->min_length && (insert + insert) < del) { //deletion
 				if (flag) {
 					cout << "store DEL " << this->getName() << endl;
@@ -1221,7 +1293,10 @@ vector<str_event> Alignment::get_events_Aln() {
 				tmp.length = del_max;
 				tmp.type |= DEL;
 				tmp.is_noise = false;
-			} else if ((mismatch+del+insert)/2 > Parameter::Instance()->min_length) { //TODO
+				if (is_N_region && del_max * Parameter::Instance()->avg_del < Parameter::Instance()->min_length) {
+					tmp.type = 0;
+				}
+			} else if ((mismatch + del + insert) / 2 > Parameter::Instance()->min_length) { //TODO
 				if (flag) {
 					cout << "store Noise" << endl;
 				}
@@ -1229,8 +1304,12 @@ vector<str_event> Alignment::get_events_Aln() {
 				tmp.type |= DEL;
 				tmp.type |= INV;
 				tmp.is_noise = true;
+				if (is_N_region || ((del_max> Parameter::Instance()->min_length && insert_max > Parameter::Instance()->min_length) && (del_max/insert_max)<Parameter::Instance()->min_length)) {
+					tmp.type = 0;
+				}
 			} else {
 				//	std::cout<<"ERROR we did not set the type!"<<std::endl;
+				tmp.type = 0;
 			}
 
 			if (flag) {
