@@ -24,7 +24,7 @@ class Parameter {
 private:
 	Parameter() {
 		window_thresh=10;//TODO check!
-		version="1.0.2";
+		version="1.0.6";
 		huge_ins = 2000;//TODO check??
 	}
 	~Parameter() {
@@ -48,6 +48,9 @@ public:
 
 	double error_rate;
 	double score_treshold;
+	double min_allelel_frequency;
+	double avg_del;
+	double avg_ins;
 	//double min_num_mismatches;
 
 	int window_thresh;
@@ -61,11 +64,14 @@ public:
 	int min_grouping_support; //min num reads supporting the overlap of two SVs
 	int huge_ins;
 	int max_dist_alns;
+	int min_segment_size;
 
 //	bool splitthreader_output;
 	bool debug;
 	bool genotype;
 	bool phase;
+	bool ignore_std;
+	bool reportBND;
 
 	void set_regions(std::string reg) {
 		size_t i = 0;
