@@ -19,6 +19,7 @@ long fuck_off(long pos, RefVector ref, std::string &chr) {
 	chr = ref[i].RefName;
 	return pos + ref[i].RefLength + (long) Parameter::Instance()->max_dist;
 }
+
 void store_pos(vector<hist_str> &positions, long pos, std::string read_name) {
 	for (size_t i = 0; i < positions.size(); i++) {
 		if (abs(positions[i].position - pos) < Parameter::Instance()->min_length) {
@@ -40,7 +41,7 @@ Breakpoint * split_points(vector<std::string> names, std::map<std::string, read_
 		new_support[names[i]] = support[names[i]];
 	}
 	position_str svs;
-	svs.start.min_pos = 0;//just to initialize. Should not be needed anymore at this stage of the prog.
+	svs.start.min_pos = 0; //just to initialize. Should not be needed anymore at this stage of the prog.
 	svs.stop.max_pos = 0;
 	svs.support = new_support;
 	Breakpoint * point = new Breakpoint(svs, (*new_support.begin()).second.coordinates.second - (*new_support.begin()).second.coordinates.first);
@@ -51,39 +52,39 @@ void detect_merged_svs(position_str point, RefVector ref, vector<Breakpoint *> &
 	new_points.clear(); //just in case!
 	vector<hist_str> pos_start;
 	vector<hist_str> pos_stop;
-
 	for (std::map<std::string, read_str>::iterator i = point.support.begin(); i != point.support.end(); i++) {
-		long pos = (*i).second.coordinates.first;
-		//std::cout<<(*i).second.coordinates.first<<" "<<(*i).second.coordinates.second<<std::endl;
-		store_pos(pos_start, pos, (*i).first);
-		pos = (*i).second.coordinates.second;
-		store_pos(pos_stop, pos, (*i).first);
+		//	std::cout << (*i).second.coordinates.first << "," << (*i).second.coordinates.second << std::endl;
+		store_pos(pos_start, (*i).second.coordinates.first, (*i).first);
+		store_pos(pos_stop, (*i).second.coordinates.second, (*i).first);
 	}
 //	std::cout << "Start: " << std::endl;
 	int start_count = 0;
+	//std::cout<<"Start pos: ";
 	for (size_t i = 0; i < pos_start.size(); i++) {
+		//std::cout<<pos_start[i].hits <<",";
 		if (pos_start[i].hits > Parameter::Instance()->min_support) {
 			start_count++;
 			/*		std::string chr = "";
-			long pos = fuck_off(pos_start[i].position, ref, chr);
-			std::cout << chr << " " << pos << ":" << pos_start[i].hits << " ; ";
-			*/
+			 long pos = fuck_off(pos_start[i].position, ref, chr);
+			 std::cout << chr << " " << pos << ":" << pos_start[i].hits << " ; ";
+			 */
 		}
 	}
 //	std::cout << std::endl;
 //	std::cout << "Stop: " << std::endl;
 	int stop_count = 0;
 	for (size_t i = 0; i < pos_stop.size(); i++) {
+		//	std::cout << pos_stop[i].hits << ",";
 		if (pos_stop[i].hits > Parameter::Instance()->min_support) {
 			stop_count++;
-		/*	std::string chr = "";
-			long pos = fuck_off(pos_stop[i].position, ref, chr);
-			std::cout << chr << " " << pos << ":" << pos_stop[i].hits << " ; ";
-			*/
+			/*	std::string chr = "";
+			 long pos = fuck_off(pos_stop[i].position, ref, chr);
+			 std::cout << chr << " " << pos << ":" << pos_stop[i].hits << " ; ";
+			 */
 		}
 	}
-//	std::cout << std::endl;
-//	std::cout << std::endl;
+	//std::cout << std::endl;
+	//std::cout << std::endl;
 
 	if (stop_count > 1 || start_count > 1) {
 		std::cout << "\tprocessing merged TRA" << std::endl;
@@ -148,41 +149,32 @@ bool should_be_stored(Breakpoint *& point) {
 	point->calc_support(); // we need that before:
 	//std::cout << "Stored: " << point->get_support() << " " << point->get_length() << std::endl;
 	if (point->get_SVtype() & TRA) { // we cannot make assumptions abut support yet.
-		return (point->get_support() > 2); // this is needed as we take each chr independently and just look at the primary alignment
+		return (point->get_support() > 1); // this is needed as we take each chr independently and just look at the primary alignment
 	} else if (point->get_support() >= Parameter::Instance()->min_support) {
 		point->predict_SV();
-		return (point->get_support() >= Parameter::Instance()->min_support && point->get_length() > Parameter::Instance()->min_length);
+		/*	std::cout<<"LEN check: "<<point->get_length()
+		 if(point->get_length() > Parameter::Instance()->min_length){
+		 cout<<" T "<<std::endl;
+		 }else{
+		 cout<<" T "<<std::endl;
+		 }*/
+		return (point->get_length() > Parameter::Instance()->min_length);
 	}
 
 	return false;
 }
 void polish_points(std::vector<Breakpoint *> & points, RefVector ref) { //TODO might be usefull! but why does the tree not fully work??
 	return;
-	if (!points.empty()) {
-
-		for (size_t i = 0; i < points.size(); i++) {
-			points[i]->predict_SV();
-			points[i]->calc_support();
-		}
-
-		for (size_t i = 0; i < points.size(); i++) {
-			if (!(points[i]->get_SVtype() & TRA)) { // we cannot make assumptions abut support yet.
-				for (size_t j = 0; j < points.size(); j++) {
-					if (!(points[j]->get_SVtype() & TRA)) {
-						if ((i != j)
-								&& (abs(points[j]->get_coordinates().start.most_support - points[i]->get_coordinates().start.most_support) < Parameter::Instance()->max_dist / 2
-										&& abs(points[j]->get_coordinates().stop.most_support - points[i]->get_coordinates().stop.most_support) < Parameter::Instance()->max_dist / 2)) {
-
-							std::string chr;
-							int pos1 = fuck_off(points[j]->get_coordinates().start.most_support, ref, chr);
-							std::cout << "HIT: " << chr << " " << pos1 << " " << TRANS_type((*points[j]->get_coordinates().support.begin()).second.SV) << " OTHER: ";
-
-							pos1 = fuck_off(points[i]->get_coordinates().start.most_support, ref, chr);
-
-							std::cout << chr << " " << pos1 << " " << TRANS_type((*points[i]->get_coordinates().support.begin()).second.SV) << std::endl;
-						}
+	for (size_t i = 0; i < points.size(); i++) {
+		if (points[i]->get_SVtype() & INS && (points[i]->get_length() == Parameter::Instance()->huge_ins)) {
+			for (size_t j = 0; j < points.size(); j++) {
+				if (i != j) {
+					if (abs(points[i]->get_coordinates().start.min_pos - points[j]->get_coordinates().start.min_pos) < Parameter::Instance()->max_dist || abs(points[i]->get_coordinates().stop.max_pos - points[j]->get_coordinates().stop.max_pos) < Parameter::Instance()->max_dist) {
+						std::cout << "HIT!: " << points[j]->get_coordinates().start.min_pos << " " << points[i]->get_coordinates().start.min_pos << " " << points[j]->get_coordinates().stop.max_pos << " " << points[i]->get_coordinates().stop.max_pos << " len: " << points[j]->get_length() << " " << points[i]->get_length() << std::endl;
+						break;
 					}
 				}
+
 			}
 		}
 	}
@@ -217,14 +209,9 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 //FILE * alt_allel_reads;
 	FILE * ref_allel_reads;
 	if (Parameter::Instance()->genotype) {
-
 		std::string output = Parameter::Instance()->tmp_file.c_str();
 		output += "ref_allele";
 		ref_allel_reads = fopen(output.c_str(), "wb");
-
-//	output = Parameter::Instance()->tmp_file.c_str();
-		//output += "alt_allele";
-		//alt_allel_reads = fopen(output.c_str(), "wb");
 	}
 	Alignment * tmp_aln = mapped_file->parseRead(Parameter::Instance()->min_mq);
 	long ref_space = get_ref_lengths(tmp_aln->getRefID(), ref);
@@ -237,12 +224,13 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 			if (current_RefID != tmp_aln->getRefID()) {
 				current_RefID = tmp_aln->getRefID();
 				ref_space = get_ref_lengths(tmp_aln->getRefID(), ref);
-				std::cout << "\tSwitch Chr " << ref[tmp_aln->getRefID()].RefName << " " << ref[tmp_aln->getRefID()].RefLength << std::endl;
+				std::cout << "\tSwitch Chr " << ref[tmp_aln->getRefID()].RefName << std::endl;//" " << ref[tmp_aln->getRefID()].RefLength
 				std::vector<Breakpoint *> points;
 				//	clarify(points);
 				bst.get_breakpoints(root, points);
 				polish_points(points, ref);
 				for (int i = 0; i < points.size(); i++) {
+
 					if (should_be_stored(points[i])) {
 						//detect_merged_svs(points[i]);
 						if (points[i]->get_SVtype() & TRA) {
@@ -308,41 +296,46 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 		num_reads++;
 
 		if (num_reads % 10000 == 0) {
-			//	curr = tmp_aln->getName();
 			cout << "\t\t# Processed reads: " << num_reads << endl;
-			/*(if (curr.size() == prev.size() && strcmp(prev.c_str(), curr.c_str()) == 0) {
-			 std::cerr << "Read occurred twice with primary alignment marked. Possibly no eof recognized in bam file." << std::endl;
-			 break;
-			 }
-			 prev = curr;*/
+			//" \r";
+			//std::cout.flush();
 		}
 	}
 //filter and copy results:
 	std::cout << "Finalizing  .." << std::endl;
 	std::vector<Breakpoint *> points;
 	bst.get_breakpoints(root, points);
-	polish_points(points, ref);
-	for (int i = 0; i < points.size(); i++) {
-		if (should_be_stored(points[i])) {
+	//std::cout<<"got breakpoints"<<std::endl;
 
+	//polish_points(points, ref);
+	for (int i = 0; i < points.size(); i++) {
+		//std::cout<<"start check"<<" "<<i<<std::endl;
+		if (should_be_stored(points[i])) {
 			if (points[i]->get_SVtype() & TRA) {
+
 				final.insert(points[i], root_final);
+				//		std::cout<<"Done insert"<<" "<<i<<std::endl;
 			} else {
+				//		std::cout<<"start print"<<" "<<i<<std::endl;
 				printer->printSV(points[i]);
+				//		std::cout<<"Done print"<<" "<<i<<std::endl;
 			}
 		}
 	}
+	//std::cout<<"Fine"<<std::endl;
 	bst.clear(root);
 	if (Parameter::Instance()->genotype) {
 		fclose(ref_allel_reads);
 	}
 //	sweep->finalyze();
+
 	points.clear();
 	final.get_breakpoints(root_final, points);
-
+	//std::cout<<"Detect merged tra"<<std::endl;
 	size_t points_size = points.size();
 	for (size_t i = 0; i < points_size; i++) { // its not nice, but I may alter the length of the vector within the loop.
 		if (points[i]->get_SVtype() & TRA) {
+
 			vector<Breakpoint *> new_points;
 			detect_merged_svs(points[i]->get_coordinates(), ref, new_points);
 			if (!new_points.empty()) {							// I only allow for 1 split!!
@@ -351,16 +344,17 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 			}
 		}
 	}
-
+	//std::cout<<"fin up"<<std::endl;
 	for (size_t i = 0; i < points.size(); i++) {
 		if (points[i]->get_SVtype() & TRA) {
 			points[i]->calc_support();
 			points[i]->predict_SV();
 		}
-		if (points[i]->get_support() > Parameter::Instance()->min_support && points[i]->get_length() > Parameter::Instance()->min_length) {
+		if (points[i]->get_support() >= Parameter::Instance()->min_support && points[i]->get_length() > Parameter::Instance()->min_length) {
 			printer->printSV(points[i]);
 		}
 	}
+	//std::cout<<"Done"<<std::endl;
 }
 
 void add_events(Alignment *& tmp, std::vector<str_event> events, short type, long ref_space, IntervallContainer & bst, TNode *&root, long read_id) {
@@ -391,6 +385,8 @@ void add_events(Alignment *& tmp, std::vector<str_event> events, short type, lon
 		}
 		//	start.support[0].read_start.min = events[i].read_pos;
 
+		read.read_strand.first = tmp->getStrand();
+		read.read_strand.second = tmp->getStrand();
 		if (flag) {
 			std::cout << tmp->getName() << " " << tmp->getRefID() << " " << svs.start.min_pos << " " << svs.stop.max_pos << " " << svs.stop.max_pos - svs.start.min_pos << std::endl;
 		}
@@ -443,7 +439,7 @@ void add_events(Alignment *& tmp, std::vector<str_event> events, short type, lon
 void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVector ref, IntervallContainer & bst, TNode *&root, long read_id) {
 	bool flag = (strcmp(tmp->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
 
-	if (false) {
+	if (flag) {
 		cout << "SPLIT: " << std::endl;
 		for (size_t i = 0; i < events.size(); i++) {
 			std::cout << events[i].pos << " stop: " << events[i].pos + events[i].length << " " << events[i].RefID << " READ: " << events[i].read_pos_start << " " << events[i].read_pos_stop;
@@ -462,6 +458,9 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 		//read.name = tmp->getName();
 		read.type = type;
 		read.SV = 0;
+		read.read_strand.first = events[i - 1].strand;
+		read.read_strand.second = events[i].strand;
+
 		//stop.support.push_back(read);
 		if (events[i].RefID == events[i - 1].RefID) { //IF different chr -> tra
 			if (events[i - 1].strand == events[i].strand) { //IF same strand -> del/ins/dup
@@ -477,37 +476,45 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 				svs.read_start = events[i - 1].read_pos_stop; // (short) events[i - 1].read_pos_start + (short) events[i - 1].length;
 				svs.read_stop = events[i].read_pos_start;
 				if (events[i - 1].strand) {
-					//	len1 = events[i - 1].pos;
-					//	len2 = events[i].pos - events[i].length;
 					svs.start.min_pos = events[i - 1].pos + events[i - 1].length + get_ref_lengths(events[i - 1].RefID, ref);
 					svs.stop.max_pos = events[i].pos + get_ref_lengths(events[i].RefID, ref);
 				} else {
-					//	len1 = events[i].pos;
-					//	len2 = events[i - 1].pos - events[i - 1].length;
 					svs.start.min_pos = events[i].pos + events[i].length + get_ref_lengths(events[i].RefID, ref);
 					svs.stop.max_pos = events[i - 1].pos + get_ref_lengths(events[i - 1].RefID, ref);
 				}
 
 				if (flag) {
-					cout << "Debug: SV_Size: " << (svs.start.min_pos - svs.stop.max_pos) << " Ref_start: " << svs.start.min_pos - get_ref_lengths(events[i].RefID, ref) << " Ref_stop: " << svs.stop.max_pos - get_ref_lengths(events[i].RefID, ref) << " readstart: " << svs.read_start << " readstop: "
-							<< svs.read_stop << std::endl;
+					cout << "Debug: SV_Size: " << (svs.start.min_pos - svs.stop.max_pos) << " tmp: " << (svs.stop.max_pos - svs.start.min_pos) << " Ref_start: " << svs.start.min_pos - get_ref_lengths(events[i].RefID, ref) << " Ref_stop: " << svs.stop.max_pos - get_ref_lengths(events[i].RefID, ref) << " readstart: " << svs.read_start << " readstop: " << svs.read_stop << std::endl;
 				}
 
-				if ((svs.stop.max_pos - svs.start.min_pos) > -1 && ((svs.stop.max_pos - svs.start.min_pos) + (Parameter::Instance()->min_length) < (svs.read_stop - svs.read_start) && (svs.read_stop - svs.read_start) > (Parameter::Instance()->min_length * 2))) {
+				if ((svs.stop.max_pos - svs.start.min_pos) > Parameter::Instance()->min_length * -1 && ((svs.stop.max_pos - svs.start.min_pos) + (Parameter::Instance()->min_length) < (svs.read_stop - svs.read_start) && (svs.read_stop - svs.read_start) > (Parameter::Instance()->min_length * 2))) {
 					if (flag) {
 						cout << "INS: " << endl;
 					}
-					read.SV |= INS;
-				} else if ((svs.start.min_pos - svs.stop.max_pos) * -1 > (svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length)) {
-					read.SV |= DEL;
-					if (flag) {
-						cout << "DEL" << endl;
+
+					if (!events[i].cross_N || (double)((svs.stop.max_pos - svs.start.min_pos) + Parameter::Instance()->min_length) < ((double)(svs.read_stop - svs.read_start) * Parameter::Instance()->avg_ins)) {
+						svs.stop.max_pos += (svs.read_stop - svs.read_start); //TODO check!
+						read.SV |= INS;
+					} else {
+						read.SV |= 'n';
 					}
+
+				} else if ((svs.start.min_pos - svs.stop.max_pos) * -1 > (svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length)) {
+					//cout << "DEL1 "<<(double)(svs.start.min_pos - svs.stop.max_pos) * Parameter::Instance()->avg_del * -1.0  <<" "<<((svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length)) << endl;
+					if (!events[i].cross_N || (double)(svs.start.min_pos - svs.stop.max_pos) * Parameter::Instance()->avg_del * -1.0 > (double)((svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length))) {
+						read.SV |= DEL;
+						if (flag) {
+							cout << "DEL2" << endl;
+						}
+					} else {
+						read.SV |= 'n';
+					}
+
 				} else if ((svs.start.min_pos - svs.stop.max_pos) > Parameter::Instance()->min_length && (svs.read_start - svs.read_stop) < Parameter::Instance()->min_length) { //check with respect to the coords of reads!
-					read.SV |= DUP;
 					if (flag) {
 						cout << "DUP: " << endl;
 					}
+					read.SV |= DUP;
 				} else {
 					if (flag) {
 						cout << "N" << endl;
@@ -518,7 +525,9 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 
 				read.strand.first = events[i - 1].strand;
 				read.strand.second = !events[i].strand;
-				if (overlaps(events[i - 1], events[i])) {
+
+				bool is_overlapping = overlaps(events[i - 1], events[i]);
+				if (is_overlapping && (events[i - 1].length > Parameter::Instance()->min_segment_size || events[i].length > Parameter::Instance()->min_segment_size)) {
 					if (flag) {
 						std::cout << "Overlap curr: " << events[i].pos << " " << events[i].pos + events[i].length << " prev: " << events[i - 1].pos << " " << events[i - 1].pos + events[i - 1].length << " " << tmp->getName() << std::endl;
 					}
@@ -541,7 +550,7 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 					//		std::cout<<"NEST: "<<svs.start.min_pos- get_ref_lengths(events[i - 1].RefID, ref) << " "<<svs.stop.max_pos - get_ref_lengths(events[i - 1].RefID, ref)<<" "<<tmp->getName()<<std::endl;
 					//	}
 					//	svs.stop.max_pos = svs.start.min_pos + Parameter::Instance()->min_length * 2;
-				} else {
+				} else if (!is_overlapping) {
 					read.SV |= INV;
 					if (events[i - 1].strand) {
 						svs.start.min_pos = events[i - 1].pos + events[i - 1].length + get_ref_lengths(events[i - 1].RefID, ref);
@@ -557,6 +566,8 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 			read.strand.first = events[i - 1].strand;
 			read.strand.second = !events[i].strand;
 			if (events[i - 1].strand == events[i].strand) {
+				//check this with + - strands!!
+
 				if (events[i - 1].strand) {
 					svs.start.min_pos = events[i - 1].pos + events[i - 1].length + get_ref_lengths(events[i - 1].RefID, ref);
 					svs.stop.max_pos = events[i].pos + get_ref_lengths(events[i].RefID, ref);
@@ -616,6 +627,20 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 				read.coordinates.first = svs.start.min_pos;
 				read.coordinates.second = svs.stop.max_pos;
 			}
+			/*	if (read.SV & TRA) {
+			 std::cout << "SPLIT: " << TRANS_type(read.SV)<<" "<<svs.start.min_pos - get_ref_lengths(events[i].RefID, ref)<<" ";
+			 if (events[i - 1].strand) {
+			 std::cout << " +";
+			 } else {
+			 std::cout << " -";
+			 }
+			 if (events[i].strand) {
+			 std::cout << " +";
+			 } else {
+			 std::cout << " -";
+			 }
+			 std::cout <<std::endl;
+			 }*/
 			/*if(read.SV & INS){
 			 std::cout<<"Split LEN: "<<abs(read.coordinates.second-read.coordinates.first)<<" Pos: "<<read.coordinates.first-get_ref_lengths(events[i - 1].RefID, ref)<<tmp->getName()<<std::endl;
 			 }*/
@@ -630,8 +655,8 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 			Breakpoint * point = new Breakpoint(svs, abs(read.coordinates.second - read.coordinates.first));
 			//std::cout<<"split ADD: " << <<" Name: "<<tmp->getName()<<" "<< svs.start.min_pos- get_ref_lengths(events[i].RefID, ref)<<"-"<<svs.stop.max_pos- get_ref_lengths(events[i].RefID, ref)<<std::endl;
 			bst.insert(point, root);
-			//		std::cout<<"Print:"<<std::endl;
-			//		bst.print(root);
+			//	std::cout<<"Print:"<<std::endl;
+			//	bst.print(root);
 		}
 	}
 }
@@ -658,40 +683,46 @@ void estimate_parameters(std::string read_filename) {
 	vector<int> scores;
 //	std::string curr, prev = "";
 	double avg_dist = 0;
-	while (!tmp_aln->getQueryBases().empty() && num < 1000) {				//1000
+	double tot_avg_ins = 0;
+	double tot_avg_del = 0;
+	while (!tmp_aln->getQueryBases().empty() && num < 1000) {	//1000
+		//	std::cout<<"test "<<tmp_aln->getName()<<std::endl;
 		if (rand() % 100 < 20 && ((tmp_aln->getAlignment()->IsPrimaryAlignment()) && (!(tmp_aln->getAlignment()->AlignmentFlag & 0x800)))) {				//}&& tmp_aln->get_is_save()))) {
 			//1. check differences in window => min_treshold for scanning!
 			//2. get score ration without checking before hand! (above if!)
 			double dist = 0;
-			vector<int> tmp = tmp_aln->get_avg_diff(dist);
-			//std::cout<<dist<<std::endl;
+			double avg_del = 0;
+			double avg_ins = 0;
+			vector<int> tmp = tmp_aln->get_avg_diff(dist, avg_del, avg_ins);
+			tot_avg_ins += avg_ins;
+			tot_avg_del += avg_del;
+			//std::cout<<"Debug:\t"<<dist<<"\t";
 			avg_dist += dist;
+			double avg_mis = 0;
 			for (size_t i = 0; i < tmp.size(); i++) {
 				while (tmp[i] + 1 > mis_per_window.size()) { //adjust length
 					mis_per_window.push_back(0);
 				}
+				avg_mis += tmp[i];
 				mis_per_window[tmp[i]]++;
 			}
-			//avg_diffs_perwindow+=tmp_aln->get_avg_diff();
+			//	std::cout <<avg_mis/tmp.size()<<"\t";
 			//get score ratio
 			double score = round(tmp_aln->get_scrore_ratio());
-			while (score + 1 > scores.size()) {
-				scores.push_back(0);
+			//	std::cout<<score<<"\t"<<std::endl;;
+			if (score > -1) {
+				while (score + 1 > scores.size()) {
+					scores.push_back(0);
+				}
+				scores[score]++;
 			}
-			scores[score]++;
 			num++;
 		}
 
 		mapped_file->parseReadFast(Parameter::Instance()->min_mq, tmp_aln);
-		/*curr = tmp_aln->getName();
-		 if (curr.size() == prev.size() && strcmp(prev.c_str(), curr.c_str()) == 0) {
-		 std::cerr << "Read occurred twice with primary alignment marked. Possibly no eof recognized in bam file." << std::endl;
-		 break;
-		 }
-		 prev = curr;*/
 	}
 	if (num == 0) {
-		std::cerr << "No reads detected in " << Parameter::Instance()->bam_files[0] << std::endl;
+		std::cerr << "Too few reads detected in " << Parameter::Instance()->bam_files[0] << std::endl;
 		exit(1);
 	}
 	vector<int> nums;
@@ -699,17 +730,14 @@ void estimate_parameters(std::string read_filename) {
 	Parameter::Instance()->max_dist_alns = floor(avg_dist / num) / 2;
 	Parameter::Instance()->window_thresh = 50;			//25;
 	if (!mis_per_window.empty()) {
-
 		for (size_t i = 0; i < mis_per_window.size(); i++) {
-			if (mis_per_window[i] != 0) {
-				//		std::cout << i << ": " << mis_per_window[i] << std::endl;
-			}
+
 			for (size_t j = 0; j < mis_per_window[i]; j++) {
 				nums.push_back(i);
 			}
 		}
 		pos = nums.size() * 0.95; //the highest 5% cutoff
-		if (pos <= nums.size()) {
+		if (pos > 0 && pos <= nums.size()) {
 			Parameter::Instance()->window_thresh = std::max(Parameter::Instance()->window_thresh, nums[pos]); //just in case we have too clean data! :)
 		}
 		nums.clear();
@@ -722,20 +750,26 @@ void estimate_parameters(std::string read_filename) {
 	}
 	pos = nums.size() * 0.05; //the lowest 5% cuttoff
 	Parameter::Instance()->score_treshold = 2; //nums[pos]; //prev=2
+
+	Parameter::Instance()->avg_del = tot_avg_del / num;
+	Parameter::Instance()->avg_ins = tot_avg_ins / num;
+
 	std::cout << "\tMax dist between aln events: " << Parameter::Instance()->max_dist_alns << std::endl;
 	std::cout << "\tMax diff in window: " << Parameter::Instance()->window_thresh << std::endl;
 	std::cout << "\tMin score ratio: " << Parameter::Instance()->score_treshold << std::endl;
+	std::cout << "\tAvg DEL ratio: " << Parameter::Instance()->avg_del << std::endl;
+	std::cout << "\tAvg INS ratio: " << Parameter::Instance()->avg_ins << std::endl;
+
 }
 
 bool overlaps(aln_str prev, aln_str curr) {
 
 	double ratio = 0;
 	double overlap = 0;
-
 	if (prev.pos + Parameter::Instance()->min_length < curr.pos + curr.length && prev.pos + prev.length - Parameter::Instance()->min_length > curr.pos) {
 		overlap = min((curr.pos + curr.length), (prev.pos + prev.length)) - max(prev.pos, curr.pos);
 		ratio = overlap / (double) min(curr.length, prev.length);
 	}
-
+//	std::cout<<overlap<<" "<<ratio<<std::endl;
 	return (ratio > 0.4 && overlap > 200);
 }
